==> xlog-message-bus-1.1.4-20230302.131331-2-sources.jar: com/xforceplus/xlog/messagebus/model/impl/MessageBusProducerListenerImpl.java <==
package com.xforceplus.xlog.messagebus.model.impl;

import com.alibaba.fastjson.JSON;
import com.xforceplus.janus.message.sdk.RequestMessage;
import com.xforceplus.janus.message.sdk.request.PubRequest;
import com.xforceplus.janus.message.sdk.response.PubResponse;
import com.xforceplus.xlog.core.model.LogContext;
import com.xforceplus.xlog.core.model.MethodListener;
import com.xforceplus.xlog.core.model.impl.MessageBusProducerLogEvent;
import com.xforceplus.xlog.core.utils.ExceptionUtil;
import com.xforceplus.xlog.logsender.model.LogSender;

import java.nio.charset.StandardCharsets;

/**
 * 消息总线生产者监听器
 *
 * @author gulei
 * @date 2023/01/19
 */
public class MessageBusProducerListenerImpl implements MethodListener {
    private static final ThreadLocal<MessageBusProducerLogEvent> cache = new ThreadLocal<>();

    private final LogSender logSender;
    private final String storeName;

    /**
     * 构造函数
     *
     * @param logSender 日志发送器
     * @param storeName 存储名称
     */
    public MessageBusProducerListenerImpl(final LogSender logSender, final String storeName) {
        this.logSender = logSender;
        this.storeName = storeName;
    }

    /**
     * 方法调用前
     *
     * @param args 方法的参数
     */
    @Override
    public void beforeCall(Object[] args) {
        final MessageBusProducerLogEvent event = new MessageBusProducerLogEvent();
        cache.set(event);

        final String traceId = LogContext.getTraceId();

        event.setStoreName(this.storeName);
        event.setTraceId(traceId);

        try {
            final PubRequest pubRequest = (PubRequest)args[0];
            event.setName(pubRequest.getPubCode());

            final RequestMessage requestMessage = pubRequest.getRequestMessage();
            final String messageText = requestMessage.getContent();

            event.setMessageText(messageText);
            event.setMessageTextSize(messageText.getBytes(StandardCharsets.UTF_8).length);
            event.setBusinessNo(requestMessage.getProperties().get("businessNo"));
            event.setMessageProperties(JSON.toJSONString(requestMessage.getProperties()));
        } catch (Throwable throwable) {
            event.setMessage("[Before]收集MessageBusProducer日志数据异常: " + ExceptionUtil.toDesc(throwable));
        }
    }

    /**
     * 方法调用后
     *
     * @param args   方法的参数
     * @param result 方法调用的结果
     */
    @Override
    public void afterCall(Object[] args, final Object result) {
        final MessageBusProducerLogEvent event = cache.get();
        cache.remove();

        try {
            final PubResponse response = (PubResponse)result;

            if (response.getSuccess()) {
                event.setMessageId(response.getMessageId());
            } else {
                event.setSuccessful(false);
                event.setMessage(response.getError());
            }
        } catch (Throwable throwable) {
            event.setMessage("[After]收集MessageBusProducer日志数据异常: " + ExceptionUtil.toDesc(throwable));
        }

        logSender.send(event);
    }

    /**
     * 方法执行过程中发生异常
     *
     * @param ex 异常
     */
    @Override
    public void onException(Throwable ex) {
        final MessageBusProducerLogEvent event = cache.get();
        cache.remove();

        event.setThrowable(ex);

        logSender.send(event);
    }
}

==> xlog-message-bus-1.1.8-20240318.074807-6-sources.jar: com/xforceplus/xlog/messagebus/model/impl/MessageBusProducerListenerImpl.java <==
package com.xforceplus.xlog.messagebus.model.impl;

import com.alibaba.fastjson.JSON;
import com.xforceplus.janus.message.sdk.RequestMessage;
import com.xforceplus.janus.message.sdk.request.PubRequest;
import com.xforceplus.janus.message.sdk.response.PubResponse;
import com.xforceplus.xlog.core.model.LogContext;
import com.xforceplus.xlog.core.model.MethodListener;
import com.xforceplus.xlog.core.model.impl.MessageBusProducerLogEvent;
import com.xforceplus.xlog.core.utils.ExceptionUtil;
import com.xforceplus.xlog.logsender.model.LogSender;

import java.nio.charset.StandardCharsets;

/**
 * 消息总线生产者监听器
 *
 * @author gulei
 * @date 2023/01/19
 */
public class MessageBusProducerListenerImpl implements MethodListener {
    private static final ThreadLocal<MessageBusProducerLogEvent> cache = new ThreadLocal<>();

    private final LogSender logSender;
    private final String storeName;

    /**
     * 构造函数
     *
     * @param logSender 日志发送器
     * @param storeName 存储名称
     */
    public MessageBusProducerListenerImpl(final LogSender logSender, final String storeName) {
        this.logSender = logSender;
        this.storeName = storeName;
    }

    /**
     * 方法调用前
     *
     * @param target 目标对象
     * @param args 方法的参数
     */
    @Override
    public void beforeCall(Object target, Object[] args) {
        final MessageBusProducerLogEvent event = new MessageBusProducerLogEvent();
        cache.set(event);

        final String traceId = LogContext.getTraceId();

        event.setStoreName(this.storeName);
        event.setTraceId(traceId);
        event.setParentTraceId(LogContext.getParentTraceId());
        event.setTenantInfo(LogContext.getTenantInfo());

        try {
            final PubRequest pubRequest = (PubRequest)args[0];
            event.setName(pubRequest.getPubCode());

            final RequestMessage requestMessage = pubRequest.getRequestMessage();
            final String messageText = requestMessage.getContent();

            event.setMessageText(messageText);
            event.setMessageTextSize(messageText.getBytes(StandardCharsets.UTF_8).length);
            event.setBusinessNo(requestMessage.getProperties().get("businessNo"));
            event.setMessageProperties(JSON.toJSONString(requestMessage.getProperties()));
        } catch (Throwable throwable) {
            event.setMessage("[Before]收集MessageBusProducer日志数据异常: " + ExceptionUtil.toDesc(throwable));
        }
    }

    /**
     * 方法调用后
     *
     * @param target 目标对象
     * @param args   方法的参数
     * @param result 方法调用的结果
     */
    @Override
    public Object afterCall(Object target, Object[] args, final Object result) {
        final MessageBusProducerLogEvent event = cache.get();
        cache.remove();

        try {
            final PubResponse response = (PubResponse)result;

            if (response.getSuccess()) {
                event.setMessageId(response.getMessageId());
            } else {
                event.setSuccessful(false);
                event.setMessage(response.getError());
            }
        } catch (Throwable throwable) {
            event.setMessage("[After]收集MessageBusProducer日志数据异常: " + ExceptionUtil.toDesc(throwable));
        }

        logSender.send(event);

        return result;
    }

    /**
     * 方法执行过程中发生异常
     *
     * @param target 目标对象
     * @param ex 异常
     */
    @Override
    public void onException(Object target, Throwable ex) {
        final MessageBusProducerLogEvent event = cache.get();
        cache.remove();

        event.setThrowable(ex);

        logSender.send(event);
    }
}
